==> haskell-yesod-form-1.4.16-133-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-form.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-form
version: 1.4.16
id: yesod-form-1.4.16-57MDizgaAeQAEfVzhHPbtk
key: yesod-form-1.4.16-57MDizgaAeQAEfVzhHPbtk
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Form handling support for Yesod Web Framework
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-form>.  Third-party packages which you can find useful: <http://hackage.haskell.org/package/yesod-form-richtext yesod-form-richtext> - richtext form fields (currntly it provides only Summernote support).
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
indefinite: False
exposed-modules:
    Yesod.Form Yesod.Form.Bootstrap3 Yesod.Form.Fields
    Yesod.Form.Functions Yesod.Form.I18n.Chinese Yesod.Form.I18n.Czech
    Yesod.Form.I18n.Dutch Yesod.Form.I18n.English
    Yesod.Form.I18n.French Yesod.Form.I18n.German
    Yesod.Form.I18n.Japanese Yesod.Form.I18n.Korean
    Yesod.Form.I18n.Norwegian Yesod.Form.I18n.Portuguese
    Yesod.Form.I18n.Russian Yesod.Form.I18n.Spanish
    Yesod.Form.I18n.Swedish Yesod.Form.Input Yesod.Form.Jquery
    Yesod.Form.MassInput Yesod.Form.Nic Yesod.Form.Types
abi: 9c21542b17e948a1fcfe224be2b612dd
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/yesod-form-1.4.16
library-dirs: /usr/lib/ghc-8.2.2/site-local/yesod-form-1.4.16
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/yesod-form-1.4.16
hs-libraries: HSyesod-form-1.4.16-57MDizgaAeQAEfVzhHPbtk
depends:
    base-4.10.1.0 yesod-core-1.4.37.3-64PSlH0y9hZJvnO0TpKa0o
    yesod-persistent-1.4.3-GqojDGflU8rFnJVVLrxuYh time-1.8.0.2
    shakespeare-2.0.15-CkAKwHonHaBO9IAOYEYQK
    persistent-2.7.3.1-Hf96hGOWQV8HWaeDkCY0LC template-haskell-2.12.0.0
    transformers-0.5.2.0 data-default-0.7.1.1-AA4CT1Ft3yBIiqFbrFdPSr
    xss-sanitize-0.3.5.7-6mNImHxMB15IzX6216xu3Y
    blaze-builder-0.4.1.0-76A6rNBvwvR8MTgrMARis4
    email-validate-2.3.2.5-4j6XSHjp8KdLdxGWMzaLqZ bytestring-0.10.8.2
    text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj
    wai-3.2.1.2-L2G3elceofc1yhjOKmecqb containers-0.5.10.2
    blaze-html-0.9.0.1-HT9MGj6kW7JIH7aaLXkr1R
    blaze-markup-0.8.2.0-CnWoybGhIGoVpPCZ0nkq3
    attoparsec-0.13.2.2-1iFrnKzrZDOGKCpRsHPeZj
    byteable-0.1.1-4PLPgH6a2E14oN7yL5y3oL
    aeson-1.2.4.0-6eoM9racNXa30gbnEGQwXU
    resourcet-1.1.11-8WS6etjZjoIGQzjhLftij3
    semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q
    network-uri-2.6.1.0-70Dn88tZogC6ueZsHNuWT3
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             yesod-core-1.4.37.3-64PSlH0y9hZJvnO0TpKa0o=ef0ca442fd5d239a61e9c76ff5f7fbd6
             yesod-persistent-1.4.3-GqojDGflU8rFnJVVLrxuYh=c97350d6018232a928d27be048c5a914
             time-1.8.0.2=7cc0324e0aef789d5f0780f6640c241b
             shakespeare-2.0.15-CkAKwHonHaBO9IAOYEYQK=fcc0dfc42d8f972e936390917f6cee9f
             persistent-2.7.3.1-Hf96hGOWQV8HWaeDkCY0LC=84a4aeb6da3bd25046040fcdbd40cbd1
             template-haskell-2.12.0.0=2257617827b0258ca46e933b344007b7
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             data-default-0.7.1.1-AA4CT1Ft3yBIiqFbrFdPSr=137eb1e83962885e435b3b188565ce6c
             xss-sanitize-0.3.5.7-6mNImHxMB15IzX6216xu3Y=3113bfee634247844ce67a35c735bffb
             blaze-builder-0.4.1.0-76A6rNBvwvR8MTgrMARis4=df56dd2a069eaa62b68a7725fcf6fae4
             email-validate-2.3.2.5-4j6XSHjp8KdLdxGWMzaLqZ=494be02a272d2c7989aaf226abd27bba
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
             wai-3.2.1.2-L2G3elceofc1yhjOKmecqb=01d341254f1cf59b77299ea88d31ec1e
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             blaze-html-0.9.0.1-HT9MGj6kW7JIH7aaLXkr1R=73d2b9544f01cd8acaf404bd9dc45c3e
             blaze-markup-0.8.2.0-CnWoybGhIGoVpPCZ0nkq3=88ae80c9035b7e1542563395a63147b4
             attoparsec-0.13.2.2-1iFrnKzrZDOGKCpRsHPeZj=9d8982f8b70cf41a2e1b007eb9382565
             byteable-0.1.1-4PLPgH6a2E14oN7yL5y3oL=24171e0673b6d1cdc40be4d3c9a33c0e
             aeson-1.2.4.0-6eoM9racNXa30gbnEGQwXU=34f15a624c6fc087743b1cf3621b819b
             resourcet-1.1.11-8WS6etjZjoIGQzjhLftij3=cf1dc27f76db31da591f7499cde81a83
             semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q=c739600aa012ae17eb506df1a043419b
             network-uri-2.6.1.0-70Dn88tZogC6ueZsHNuWT3=afebcc3944e17103658dd7506cfde008
haddock-interfaces: /usr/share/doc/haskell-yesod-form/html/yesod-form.haddock
haddock-html: /usr/share/doc/haskell-yesod-form/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-form-1.4.16-137-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-form.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-form
version: 1.4.16
id: yesod-form-1.4.16-Bmql0cZPp5a8VELcZR2Lxo
key: yesod-form-1.4.16-Bmql0cZPp5a8VELcZR2Lxo
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Form handling support for Yesod Web Framework
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-form>.  Third-party packages which you can find useful: <http://hackage.haskell.org/package/yesod-form-richtext yesod-form-richtext> - richtext form fields (currntly it provides only Summernote support).
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
indefinite: False
exposed-modules:
    Yesod.Form Yesod.Form.Bootstrap3 Yesod.Form.Fields
    Yesod.Form.Functions Yesod.Form.I18n.Chinese Yesod.Form.I18n.Czech
    Yesod.Form.I18n.Dutch Yesod.Form.I18n.English
    Yesod.Form.I18n.French Yesod.Form.I18n.German
    Yesod.Form.I18n.Japanese Yesod.Form.I18n.Korean
    Yesod.Form.I18n.Norwegian Yesod.Form.I18n.Portuguese
    Yesod.Form.I18n.Russian Yesod.Form.I18n.Spanish
    Yesod.Form.I18n.Swedish Yesod.Form.Input Yesod.Form.Jquery
    Yesod.Form.MassInput Yesod.Form.Nic Yesod.Form.Types
abi: de29069c1bb7f79c4a2a017da7844005
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/yesod-form-1.4.16
library-dirs: /usr/lib/ghc-8.2.2/site-local/yesod-form-1.4.16
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/yesod-form-1.4.16
hs-libraries: HSyesod-form-1.4.16-Bmql0cZPp5a8VELcZR2Lxo
depends:
    base-4.10.1.0 yesod-core-1.4.37.3-3gn5jv7IONcGgKJq5zIcAg
    yesod-persistent-1.4.3-9aokd3KNGxGCqfWKgoC8QB time-1.8.0.2
    shakespeare-2.0.15-CkAKwHonHaBO9IAOYEYQK
    persistent-2.7.3.1-3F7EqlsyxpB2VYnyk6dK4Y template-haskell-2.12.0.0
    transformers-0.5.2.0 data-default-0.7.1.1-AA4CT1Ft3yBIiqFbrFdPSr
    xss-sanitize-0.3.5.7-6mNImHxMB15IzX6216xu3Y
    blaze-builder-0.4.1.0-76A6rNBvwvR8MTgrMARis4
    email-validate-2.3.2.5-4j6XSHjp8KdLdxGWMzaLqZ bytestring-0.10.8.2
    text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj
    wai-3.2.1.2-L2G3elceofc1yhjOKmecqb containers-0.5.10.2
    blaze-html-0.9.0.1-HT9MGj6kW7JIH7aaLXkr1R
    blaze-markup-0.8.2.0-CnWoybGhIGoVpPCZ0nkq3
    attoparsec-0.13.2.2-1iFrnKzrZDOGKCpRsHPeZj
    byteable-0.1.1-4PLPgH6a2E14oN7yL5y3oL
    aeson-1.2.4.0-6eoM9racNXa30gbnEGQwXU
    resourcet-1.1.11-8WS6etjZjoIGQzjhLftij3
    semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q
    network-uri-2.6.1.0-70Dn88tZogC6ueZsHNuWT3
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             yesod-core-1.4.37.3-3gn5jv7IONcGgKJq5zIcAg=65c354b65f8cd4b75e3006ded88c4135
             yesod-persistent-1.4.3-9aokd3KNGxGCqfWKgoC8QB=d4dc1db68efbb5602eeeedcf12c6e573
             time-1.8.0.2=7cc0324e0aef789d5f0780f6640c241b
             shakespeare-2.0.15-CkAKwHonHaBO9IAOYEYQK=fcc0dfc42d8f972e936390917f6cee9f
             persistent-2.7.3.1-3F7EqlsyxpB2VYnyk6dK4Y=9d29ae2e2052de6eaf93e52a8314eb1a
             template-haskell-2.12.0.0=2257617827b0258ca46e933b344007b7
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             data-default-0.7.1.1-AA4CT1Ft3yBIiqFbrFdPSr=137eb1e83962885e435b3b188565ce6c
             xss-sanitize-0.3.5.7-6mNImHxMB15IzX6216xu3Y=3113bfee634247844ce67a35c735bffb
             blaze-builder-0.4.1.0-76A6rNBvwvR8MTgrMARis4=df56dd2a069eaa62b68a7725fcf6fae4
             email-validate-2.3.2.5-4j6XSHjp8KdLdxGWMzaLqZ=494be02a272d2c7989aaf226abd27bba
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
             wai-3.2.1.2-L2G3elceofc1yhjOKmecqb=01d341254f1cf59b77299ea88d31ec1e
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             blaze-html-0.9.0.1-HT9MGj6kW7JIH7aaLXkr1R=73d2b9544f01cd8acaf404bd9dc45c3e
             blaze-markup-0.8.2.0-CnWoybGhIGoVpPCZ0nkq3=88ae80c9035b7e1542563395a63147b4
             attoparsec-0.13.2.2-1iFrnKzrZDOGKCpRsHPeZj=9d8982f8b70cf41a2e1b007eb9382565
             byteable-0.1.1-4PLPgH6a2E14oN7yL5y3oL=24171e0673b6d1cdc40be4d3c9a33c0e
             aeson-1.2.4.0-6eoM9racNXa30gbnEGQwXU=34f15a624c6fc087743b1cf3621b819b
             resourcet-1.1.11-8WS6etjZjoIGQzjhLftij3=cf1dc27f76db31da591f7499cde81a83
             semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q=c739600aa012ae17eb506df1a043419b
             network-uri-2.6.1.0-70Dn88tZogC6ueZsHNuWT3=afebcc3944e17103658dd7506cfde008
haddock-interfaces: /usr/share/doc/haskell-yesod-form/html/yesod-form.haddock
haddock-html: /usr/share/doc/haskell-yesod-form/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
